# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './snitch/ui/settings.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SettingsDialog(object):
    def setupUi(self, SettingsDialog):
        SettingsDialog.setObjectName("SettingsDialog")
        SettingsDialog.resize(450, 250)
        self.verticalLayout = QtWidgets.QVBoxLayout(SettingsDialog)
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBoxGeneral = QtWidgets.QGroupBox(SettingsDialog)
        self.groupBoxGeneral.setObjectName("groupBoxGeneral")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBoxGeneral)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(self.groupBoxGeneral)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(102, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 1, 1, 1)
        self.valueMaxRecent = QtWidgets.QSpinBox(self.groupBoxGeneral)
        self.valueMaxRecent.setMinimumSize(QtCore.QSize(60, 0))
        self.valueMaxRecent.setMinimum(1)
        self.valueMaxRecent.setMaximum(25)
        self.valueMaxRecent.setObjectName("valueMaxRecent")
        self.gridLayout.addWidget(self.valueMaxRecent, 0, 2, 1, 1)
        self.verticalLayout.addWidget(self.groupBoxGeneral)
        self.groupBoxRecording = QtWidgets.QGroupBox(SettingsDialog)
        self.groupBoxRecording.setObjectName("groupBoxRecording")
        self.formLayout = QtWidgets.QFormLayout(self.groupBoxRecording)
        self.formLayout.setObjectName("formLayout")
        self.checkBoxMinimizeOnRecord = QtWidgets.QCheckBox(self.groupBoxRecording)
        self.checkBoxMinimizeOnRecord.setObjectName("checkBoxMinimizeOnRecord")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.checkBoxMinimizeOnRecord)
        self.verticalLayout.addWidget(self.groupBoxRecording)
        self.groupBoxPlayback = QtWidgets.QGroupBox(SettingsDialog)
        self.groupBoxPlayback.setObjectName("groupBoxPlayback")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBoxPlayback)
        self.gridLayout_2.setObjectName("gridLayout_2")
        spacerItem1 = QtWidgets.QSpacerItem(80, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_2.addItem(spacerItem1, 0, 1, 1, 1)
        self.labelPlaybackDelay = QtWidgets.QLabel(self.groupBoxPlayback)
        self.labelPlaybackDelay.setObjectName("labelPlaybackDelay")
        self.gridLayout_2.addWidget(self.labelPlaybackDelay, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBoxPlayback)
        self.label_2.setObjectName("label_2")
        self.gridLayout_2.addWidget(self.label_2, 3, 0, 1, 1)
        self.valuePlaybackDelay = QtWidgets.QDoubleSpinBox(self.groupBoxPlayback)
        self.valuePlaybackDelay.setMinimumSize(QtCore.QSize(60, 0))
        self.valuePlaybackDelay.setDecimals(1)
        self.valuePlaybackDelay.setMinimum(-1.0)
        self.valuePlaybackDelay.setSingleStep(0.1)
        self.valuePlaybackDelay.setProperty("value", 0.2)
        self.valuePlaybackDelay.setObjectName("valuePlaybackDelay")
        self.gridLayout_2.addWidget(self.valuePlaybackDelay, 0, 2, 1, 1)
        self.valueDiffThreshold = QtWidgets.QSpinBox(self.groupBoxPlayback)
        self.valueDiffThreshold.setEnabled(True)
        self.valueDiffThreshold.setMaximum(100)
        self.valueDiffThreshold.setProperty("value", 100)
        self.valueDiffThreshold.setObjectName("valueDiffThreshold")
        self.gridLayout_2.addWidget(self.valueDiffThreshold, 3, 2, 1, 1)
        self.valueDiffThresholdSlider = QtWidgets.QSlider(self.groupBoxPlayback)
        self.valueDiffThresholdSlider.setMinimumSize(QtCore.QSize(150, 0))
        self.valueDiffThresholdSlider.setMinimum(50)
        self.valueDiffThresholdSlider.setMaximum(100)
        self.valueDiffThresholdSlider.setProperty("value", 100)
        self.valueDiffThresholdSlider.setOrientation(QtCore.Qt.Horizontal)
        self.valueDiffThresholdSlider.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.valueDiffThresholdSlider.setObjectName("valueDiffThresholdSlider")
        self.gridLayout_2.addWidget(self.valueDiffThresholdSlider, 3, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBoxPlayback)
        self.buttonBox = QtWidgets.QDialogButtonBox(SettingsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)

        self.retranslateUi(SettingsDialog)
        self.buttonBox.accepted.connect(SettingsDialog.accept)
        self.buttonBox.rejected.connect(SettingsDialog.reject)
        self.valueDiffThresholdSlider.valueChanged['int'].connect(self.valueDiffThreshold.setValue)
        self.valueDiffThreshold.valueChanged['int'].connect(self.valueDiffThresholdSlider.setValue)
        QtCore.QMetaObject.connectSlotsByName(SettingsDialog)

    def retranslateUi(self, SettingsDialog):
        _translate = QtCore.QCoreApplication.translate
        SettingsDialog.setWindowTitle(_translate("SettingsDialog", "Snitch preferences"))
        self.groupBoxGeneral.setTitle(_translate("SettingsDialog", "General"))
        self.label.setText(_translate("SettingsDialog", "Max number of recent files: "))
        self.groupBoxRecording.setTitle(_translate("SettingsDialog", "Event recordinq"))
        self.checkBoxMinimizeOnRecord.setText(_translate("SettingsDialog", "Minimize when recording"))
        self.groupBoxPlayback.setTitle(_translate("SettingsDialog", "Event playback"))
        self.labelPlaybackDelay.setText(_translate("SettingsDialog", "Delay between replayed events:"))
        self.label_2.setText(_translate("SettingsDialog", "Diff threshold:"))
        self.valuePlaybackDelay.setSuffix(_translate("SettingsDialog", "s"))
        self.valueDiffThreshold.setSuffix(_translate("SettingsDialog", "%"))
