# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './snitch/ui/controller.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Controller(object):
    def setupUi(self, Controller):
        Controller.setObjectName("Controller")
        Controller.resize(1024, 650)
        Controller.setWindowTitle("Snitch")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/eyecandy/ui/icons/snitch.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Controller.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(Controller)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.splitter = QtWidgets.QSplitter(self.centralwidget)
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setHandleWidth(9)
        self.splitter.setChildrenCollapsible(False)
        self.splitter.setObjectName("splitter")
        self.eventPanel = QtWidgets.QWidget(self.splitter)
        self.eventPanel.setObjectName("eventPanel")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.eventPanel)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.eventSplitter = QtWidgets.QSplitter(self.eventPanel)
        self.eventSplitter.setOrientation(QtCore.Qt.Horizontal)
        self.eventSplitter.setHandleWidth(6)
        self.eventSplitter.setObjectName("eventSplitter")
        self.tableEvents = QtWidgets.QTableView(self.eventSplitter)
        self.tableEvents.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tableEvents.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableEvents.setObjectName("tableEvents")
        self.tableEvents.horizontalHeader().setDefaultSectionSize(128)
        self.tableEvents.horizontalHeader().setStretchLastSection(True)
        self.tableEvents.verticalHeader().setDefaultSectionSize(20)
        self.layoutWidget = QtWidgets.QWidget(self.eventSplitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.tableProperties = QtWidgets.QTableView(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.tableProperties.sizePolicy().hasHeightForWidth())
        self.tableProperties.setSizePolicy(sizePolicy)
        self.tableProperties.setMinimumSize(QtCore.QSize(198, 0))
        font = QtGui.QFont()
        font.setPointSize(8)
        self.tableProperties.setFont(font)
        self.tableProperties.setFocusPolicy(QtCore.Qt.TabFocus)
        self.tableProperties.setAlternatingRowColors(True)
        self.tableProperties.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tableProperties.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableProperties.setObjectName("tableProperties")
        self.tableProperties.horizontalHeader().setDefaultSectionSize(80)
        self.tableProperties.horizontalHeader().setStretchLastSection(True)
        self.tableProperties.verticalHeader().setVisible(False)
        self.tableProperties.verticalHeader().setDefaultSectionSize(18)
        self.verticalLayout_2.addWidget(self.tableProperties)
        self.eventMgmtButtons = EventMgmtButtons(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.eventMgmtButtons.sizePolicy().hasHeightForWidth())
        self.eventMgmtButtons.setSizePolicy(sizePolicy)
        self.eventMgmtButtons.setMinimumSize(QtCore.QSize(0, 32))
        self.eventMgmtButtons.setMaximumSize(QtCore.QSize(16777215, 32))
        self.eventMgmtButtons.setObjectName("eventMgmtButtons")
        self.verticalLayout_2.addWidget(self.eventMgmtButtons)
        self.verticalLayout_3.addWidget(self.eventSplitter)
        self.snapshotPanel = QtWidgets.QWidget(self.splitter)
        self.snapshotPanel.setObjectName("snapshotPanel")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.snapshotPanel)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.snapshotSplitter = QtWidgets.QSplitter(self.snapshotPanel)
        self.snapshotSplitter.setOrientation(QtCore.Qt.Horizontal)
        self.snapshotSplitter.setHandleWidth(6)
        self.snapshotSplitter.setObjectName("snapshotSplitter")
        self.listSnap = QtWidgets.QListView(self.snapshotSplitter)
        self.listSnap.setObjectName("listSnap")
        self.layoutWidget1 = QtWidgets.QWidget(self.snapshotSplitter)
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.labelPreview = AspectRatioPixmapLabel(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelPreview.sizePolicy().hasHeightForWidth())
        self.labelPreview.setSizePolicy(sizePolicy)
        self.labelPreview.setMinimumSize(QtCore.QSize(198, 150))
        self.labelPreview.setMaximumSize(QtCore.QSize(16777215, 150))
        self.labelPreview.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.labelPreview.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.labelPreview.setText("")
        self.labelPreview.setPixmap(QtGui.QPixmap(":/eyecandy/ui/icons/snitch_a30.png"))
        self.labelPreview.setAlignment(QtCore.Qt.AlignCenter)
        self.labelPreview.setObjectName("labelPreview")
        self.verticalLayout_4.addWidget(self.labelPreview)
        self.tableSnapProps = QtWidgets.QTableView(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.tableSnapProps.sizePolicy().hasHeightForWidth())
        self.tableSnapProps.setSizePolicy(sizePolicy)
        self.tableSnapProps.setMinimumSize(QtCore.QSize(198, 0))
        font = QtGui.QFont()
        font.setPointSize(8)
        self.tableSnapProps.setFont(font)
        self.tableSnapProps.setAlternatingRowColors(True)
        self.tableSnapProps.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.tableSnapProps.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.tableSnapProps.setObjectName("tableSnapProps")
        self.tableSnapProps.horizontalHeader().setDefaultSectionSize(80)
        self.tableSnapProps.horizontalHeader().setStretchLastSection(True)
        self.tableSnapProps.verticalHeader().setVisible(False)
        self.tableSnapProps.verticalHeader().setDefaultSectionSize(18)
        self.verticalLayout_4.addWidget(self.tableSnapProps)
        self.capsEventMgmtButtons = EventMgmtButtons(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.capsEventMgmtButtons.sizePolicy().hasHeightForWidth())
        self.capsEventMgmtButtons.setSizePolicy(sizePolicy)
        self.capsEventMgmtButtons.setMinimumSize(QtCore.QSize(0, 32))
        self.capsEventMgmtButtons.setMaximumSize(QtCore.QSize(16777215, 32))
        self.capsEventMgmtButtons.setObjectName("capsEventMgmtButtons")
        self.verticalLayout_4.addWidget(self.capsEventMgmtButtons)
        self.verticalLayout_5.addWidget(self.snapshotSplitter)
        self.verticalLayout.addWidget(self.splitter)
        Controller.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(Controller)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1024, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuOpenRecent = QtWidgets.QMenu(self.menuFile)
        self.menuOpenRecent.setObjectName("menuOpenRecent")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuOptions = QtWidgets.QMenu(self.menubar)
        self.menuOptions.setObjectName("menuOptions")
        self.menuActions = QtWidgets.QMenu(self.menubar)
        self.menuActions.setObjectName("menuActions")
        Controller.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(Controller)
        self.statusbar.setObjectName("statusbar")
        Controller.setStatusBar(self.statusbar)
        self.toolbarEvents = QtWidgets.QToolBar(Controller)
        self.toolbarEvents.setIconSize(QtCore.QSize(32, 32))
        self.toolbarEvents.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.toolbarEvents.setObjectName("toolbarEvents")
        Controller.addToolBar(QtCore.Qt.TopToolBarArea, self.toolbarEvents)
        self.toolBarScreenshots = QtWidgets.QToolBar(Controller)
        self.toolBarScreenshots.setIconSize(QtCore.QSize(32, 32))
        self.toolBarScreenshots.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.toolBarScreenshots.setObjectName("toolBarScreenshots")
        Controller.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarScreenshots)
        self.toolBarFiles = QtWidgets.QToolBar(Controller)
        self.toolBarFiles.setIconSize(QtCore.QSize(32, 32))
        self.toolBarFiles.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.toolBarFiles.setObjectName("toolBarFiles")
        Controller.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBarFiles)
        self.actionAbout = QtWidgets.QAction(Controller)
        self.actionAbout.setObjectName("actionAbout")
        self.actionQuit = QtWidgets.QAction(Controller)
        self.actionQuit.setObjectName("actionQuit")
        self.actionRecord = QtWidgets.QAction(Controller)
        self.actionRecord.setCheckable(True)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/controls/ui/icons/record.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionRecord.setIcon(icon1)
        self.actionRecord.setObjectName("actionRecord")
        self.actionStop = QtWidgets.QAction(Controller)
        self.actionStop.setEnabled(False)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/controls/ui/icons/stop.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionStop.setIcon(icon2)
        self.actionStop.setObjectName("actionStop")
        self.actionSave = QtWidgets.QAction(Controller)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/controls/ui/icons/accept.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionSave.setIcon(icon3)
        self.actionSave.setObjectName("actionSave")
        self.actionOpen = QtWidgets.QAction(Controller)
        self.actionOpen.setObjectName("actionOpen")
        self.actionMinimizeWhenRecording = QtWidgets.QAction(Controller)
        self.actionMinimizeWhenRecording.setCheckable(True)
        self.actionMinimizeWhenRecording.setObjectName("actionMinimizeWhenRecording")
        self.actionSettings = QtWidgets.QAction(Controller)
        self.actionSettings.setObjectName("actionSettings")
        self.actionPlay = QtWidgets.QAction(Controller)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/controls/ui/icons/play.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPlay.setIcon(icon4)
        self.actionPlay.setObjectName("actionPlay")
        self.actionAddScreenshot = QtWidgets.QAction(Controller)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/controls/ui/icons/image_add.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionAddScreenshot.setIcon(icon5)
        self.actionAddScreenshot.setObjectName("actionAddScreenshot")
        self.actionPlayScreenshots = QtWidgets.QAction(Controller)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/controls/ui/icons/image_next.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionPlayScreenshots.setIcon(icon6)
        self.actionPlayScreenshots.setObjectName("actionPlayScreenshots")
        self.actionShowDiff = QtWidgets.QAction(Controller)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/controls/ui/icons/page_swap.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionShowDiff.setIcon(icon7)
        self.actionShowDiff.setObjectName("actionShowDiff")
        self.actionOCR = QtWidgets.QAction(Controller)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/controls/ui/icons/image_edit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionOCR.setIcon(icon8)
        self.actionOCR.setObjectName("actionOCR")
        self.actionClear = QtWidgets.QAction(Controller)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/controls/ui/icons/remove.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.actionClear.setIcon(icon9)
        self.actionClear.setObjectName("actionClear")
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.menuOpenRecent.menuAction())
        self.menuFile.addAction(self.actionSave)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuHelp.addAction(self.actionAbout)
        self.menuOptions.addAction(self.actionSettings)
        self.menuActions.addAction(self.actionRecord)
        self.menuActions.addAction(self.actionStop)
        self.menuActions.addAction(self.actionPlay)
        self.menuActions.addSeparator()
        self.menuActions.addAction(self.actionAddScreenshot)
        self.menuActions.addAction(self.actionPlayScreenshots)
        self.menuActions.addAction(self.actionShowDiff)
        self.menuActions.addAction(self.actionOCR)
        self.menuActions.addSeparator()
        self.menuActions.addAction(self.actionClear)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuActions.menuAction())
        self.menubar.addAction(self.menuOptions.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())
        self.toolbarEvents.addAction(self.actionRecord)
        self.toolbarEvents.addAction(self.actionStop)
        self.toolBarScreenshots.addAction(self.actionAddScreenshot)
        self.toolBarScreenshots.addSeparator()
        self.toolBarScreenshots.addAction(self.actionPlayScreenshots)
        self.toolBarScreenshots.addAction(self.actionShowDiff)
        self.toolBarScreenshots.addAction(self.actionOCR)
        self.toolBarFiles.addAction(self.actionPlay)
        self.toolBarFiles.addSeparator()
        self.toolBarFiles.addAction(self.actionSave)
        self.toolBarFiles.addAction(self.actionClear)

        self.retranslateUi(Controller)
        self.actionQuit.triggered.connect(Controller.close)
        self.actionAbout.triggered.connect(Controller.show_about_dialog)
        self.actionSave.triggered.connect(Controller.show_save_dialog)
        self.actionOpen.triggered.connect(Controller.show_open_dialog)
        self.actionSettings.triggered.connect(Controller.show_settings_dialog)
        self.actionRecord.toggled['bool'].connect(self.actionStop.setEnabled)
        self.menuOpenRecent.triggered['QAction*'].connect(Controller.open_recent)
        QtCore.QMetaObject.connectSlotsByName(Controller)

    def retranslateUi(self, Controller):
        _translate = QtCore.QCoreApplication.translate
        self.menuFile.setTitle(_translate("Controller", "File"))
        self.menuOpenRecent.setTitle(_translate("Controller", "Open recent"))
        self.menuHelp.setTitle(_translate("Controller", "Help"))
        self.menuOptions.setTitle(_translate("Controller", "Options"))
        self.menuActions.setTitle(_translate("Controller", "Actions"))
        self.toolbarEvents.setWindowTitle(_translate("Controller", "Record control"))
        self.toolBarScreenshots.setWindowTitle(_translate("Controller", "Screenshot management"))
        self.toolBarFiles.setWindowTitle(_translate("Controller", "General"))
        self.actionAbout.setText(_translate("Controller", "About…"))
        self.actionQuit.setText(_translate("Controller", "&Quit"))
        self.actionRecord.setText(_translate("Controller", "Record"))
        self.actionStop.setText(_translate("Controller", "Stop"))
        self.actionSave.setText(_translate("Controller", "Save…"))
        self.actionOpen.setText(_translate("Controller", "Open…"))
        self.actionMinimizeWhenRecording.setText(_translate("Controller", "Minimize when recording"))
        self.actionSettings.setText(_translate("Controller", "Settings…"))
        self.actionPlay.setText(_translate("Controller", "Play"))
        self.actionAddScreenshot.setText(_translate("Controller", "Add screenshot"))
        self.actionPlayScreenshots.setText(_translate("Controller", "Play screenshots"))
        self.actionShowDiff.setText(_translate("Controller", "Show diff"))
        self.actionOCR.setText(_translate("Controller", "OCR"))
        self.actionClear.setText(_translate("Controller", "Clear"))
from snitch.ui.aspect_ratio_pixmap_label import AspectRatioPixmapLabel
from snitch.ui.list_manager import EventMgmtButtons
from snitch import assets_rc
